import"./outputWidgets.b00cf7e9.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="09e9b21f-c30b-4cf4-98ba-5f3072afb1de",x._sentryDebugIdIdentifier="sentry-dbid-09e9b21f-c30b-4cf4-98ba-5f3072afb1de")}catch{}})();const d=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{d as u};
//# sourceMappingURL=uuid.564748f2.js.map
