import{S as p}from"./Sidebar.b93bfb48.js";import{_ as d}from"./Navbar.vue_vue_type_script_setup_true_lang.2fa1cf2b.js";import{G as c,H as l,I as u}from"./icons.99873bd8.js";import{d as b,ez as f,F as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.b00cf7e9.js";import{a as z}from"./asyncComputed.1f0126f2.js";import"./router.7caa92ea.js";import"./jwt-decode.esm.74bd4619.js";import"./index.1aa24eee.js";import{O as w}from"./organization.cd688c81.js";import{B as I}from"./BaseLayout.737caf54.js";import"./index.47033021.js";import"./logo.084e5d7c.js";import"./Text.20fe3ce1.js";import"./index.0d76c058.js";import"./FormItem.4a1fd62e.js";import"./hasIn.606210e6.js";import"./storage.c80f95dc.js";import"./index.d1e02be5.js";import"./index.cf4c23b9.js";import"./record.2bf8fb00.js";import"./pubsub.b6fbda2c.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="e567e177-6da3-4633-9f07-def3731d21b3",o._sentryDebugIdIdentifier="sentry-dbid-e567e177-6da3-4633-9f07-def3731d21b3")}catch{}})();const K=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:t}=z(()=>w.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:c,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(h,B)=>{const m=_("router-view");return y(),v(I,null,{navbar:a(()=>[r(d,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.63a3d0fa.js.map
