import{C as n,A as d}from"./CollapsePanel.db0264d1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8c65c1d8-f263-4d70-8ddc-4b33b1f83161",e._sentryDebugIdIdentifier="sentry-dbid-8c65c1d8-f263-4d70-8ddc-4b33b1f83161")}catch{}})();n.Panel=d;n.install=function(e){return e.component(n.name,n),e.component(d.name,d),e};
//# sourceMappingURL=index.6916e4b8.js.map
