import{N as l}from"./NavbarControls.e2e8ff8e.js";import{d as _,ey as f,ez as y,F as g,a as v,b as c,et as h,f as e,w as s,u as a,e as k,bo as w,ao as S,c as x,eS as T,t as q}from"./outputWidgets.b00cf7e9.js";import{A as C}from"./Text.20fe3ce1.js";import{T as I,A as o}from"./TabPane.42b37be1.js";import{c as A}from"./index.0d76c058.js";import"./asyncComputed.1f0126f2.js";import"./index.24187c91.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.1a9808bf.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.7c6446dc.js";import"./ant-design.2d18431c.js";import"./index.d004fd61.js";import"./Modal.f98e25b2.js";import"./storage.c80f95dc.js";import"./Link.29c2dd22.js";import"./index.77ec4d5c.js";import"./Title.334eceae.js";import"./index.c775a6c6.js";import"./workspaces.00b9975d.js";import"./record.2bf8fb00.js";import"./pubsub.b6fbda2c.js";import"./url.255821a6.js";import"./popupNotifcation.b91c8b3b.js";import"./CircularLoading.432b1cc5.js";import"./icons.99873bd8.js";import"./index.4b86cc41.js";import"./hasIn.606210e6.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="943632bf-175b-4925-ac78-b03739bde4a7",r._sentryDebugIdIdentifier="sentry-dbid-943632bf-175b-4925-ac78-b03739bde4a7")}catch{}})();const B={class:"content"},D=_({__name:"Settings",setup(r){const t=f(),n=y();function m(){t.push({name:"home"})}const p=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function u(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(a(A),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(l,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(a(C),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(a(I),{"active-key":p.value,onChange:u},{default:s(()=>[e(a(o),{key:"style",tab:"Style"}),e(a(o),{key:"sidebar",tab:"Sidebar"}),e(a(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",B,[e(d,null,{default:s(({Component:b})=>[(c(),x(T(b)))]),_:1})])],64)}}});const oe=q(D,[["__scopeId","data-v-772f4b10"]]);export{oe as default};
//# sourceMappingURL=Settings.f767dc41.js.map
