import{cu as n}from"./outputWidgets.b00cf7e9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="ab339994-2366-45fa-b936-440cee95bcc2",e._sentryDebugIdIdentifier="sentry-dbid-ab339994-2366-45fa-b936-440cee95bcc2")}catch{}})();const d=(e,r)=>{n.error({message:e,description:r})};export{d as p};
//# sourceMappingURL=popupNotifcation.b91c8b3b.js.map
