import{C as t,E as d,K as i,a as c,M as f,c as l,P as y,R as b,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.f66c5d57.js";import"./outputWidgets.b00cf7e9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a25ad980-a195-49b1-a92c-8fe385c192d6",e._sentryDebugIdIdentifier="sentry-dbid-a25ad980-a195-49b1-a92c-8fe385c192d6")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,c as KeyMod,f as MarkerSeverity,l as MarkerTag,y as Position,b as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.f99661e2.js.map
