import{t as r,a,b as i,c,i as d,T as p,j as _,P as u,C as f,M as l,s as g,k as s,l as m,m as y,n as b,p as v}from"./outputWidgets.b00cf7e9.js";import{s as w,a as o}from"./index.24187c91.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8721a1fe-2c3d-4d7a-8b4d-7274c374e055",e._sentryDebugIdIdentifier="sentry-dbid-8721a1fe-2c3d-4d7a-8b4d-7274c374e055")}catch{}})();const h={};function I(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=r(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=d({render:()=>m(k)});p.init(),_(e,o),x.init(),e.use(o),e.use(u),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,b),s(e,v)})();
//# sourceMappingURL=player.beca5979.js.map
